@@ -41,6 +41,7 @@ import javax.xml.datatype.XMLGregorianCalendar;
  *         &lt;element name="country_home" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
  *         &lt;element name="country_other" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
  *         &lt;element name="defaultSenderAddress" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
+ *         &lt;element name="driveUserFolderMode" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
  *         &lt;element name="default_group" type="{http://dataobjects.soap.admin.openexchange.com/xsd}Group" minOccurs="0"/>
  *         &lt;element name="department" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
  *         &lt;element name="display_name" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
@@ -151,6 +152,7 @@ import javax.xml.datatype.XMLGregorianCalendar;
  *         &lt;element name="userfield18" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
  *         &lt;element name="userfield19" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
  *         &lt;element name="userfield20" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
+ *         &lt;element name="convert_drive_user_folders" type="{http://www.w3.org/2001/XMLSchema}boolean" minOccurs="0"/>
  *       &lt;/sequence>
  *     &lt;/restriction>
  *   &lt;/complexContent>
@@ -179,6 +181,7 @@ import javax.xml.datatype.XMLGregorianCalendar;
     "countryBusiness",
     "countryHome",
     "countryOther",
+    "driveUserFolderMode",
     "defaultSenderAddress",
     "defaultGroup",
     "department",
@@ -290,7 +293,8 @@ import javax.xml.datatype.XMLGregorianCalendar;
     "userfield17",
     "userfield18",
     "userfield19",
-    "userfield20"
+    "userfield20",
+    "convertDriveUserFolders"
 })
 public class User {
 
@@ -331,6 +335,8 @@ public class User {
     protected String countryHome;
     @XmlElement(name = "country_other", nillable = true)
     protected String countryOther;
+    @XmlElement(name = "drive_folder_mode", nillable = true)
+    protected String driveUserFolderMode;
     @XmlElement(nillable = true)
     protected String defaultSenderAddress;
     @XmlElement(name = "default_group", nillable = true)
@@ -553,6 +559,8 @@ public class User {
     protected String userfield19;
     @XmlElement(nillable = true)
     protected String userfield20;
+    @XmlElement(name = "convert_drive_user_folders", nillable = true)
+    protected Boolean convertDriveUserFolders;
 
     /**
      * Gets the value of the aliases property.
@@ -1011,6 +1019,30 @@ public class User {
     public void setDefaultSenderAddress(final String value) {
         this.defaultSenderAddress = value;
     }
+    
+
+    /**
+     * Get driveUserFolderMode value.
+     * 
+     * @return
+     *      possible object is
+     *     {@link String }
+     */
+    public String getDriveUserFolderMode() {
+        return driveUserFolderMode;
+    }
+
+    /**
+     * Set driveUserFolderMode value..
+     *
+     * @param value
+     *     allowed object is
+     *     {@link String }
+     *
+     */
+    public void setDriveUserFolderMode(String value) {
+        this.driveUserFolderMode = value;
+    }
 
     /**
      * Ruft den Wert der defaultGroup-Eigenschaft ab.
@@ -3724,4 +3756,12 @@ public class User {
         this.userfield20 = value;
     }
 
+    public Boolean isConvertDriveUserFolders() {
+        return this.convertDriveUserFolders;
+    }
+
+    public void setConvertDriveUserFolders(Boolean convertDriveUserFolders) {
+        this.convertDriveUserFolders = convertDriveUserFolders;
+    }
+
 }
